@@ -37,6 +37,12 @@ class MatWrap:
         mw.mpl()  # returns `matplotlib` module
         mw.plt()  # returns `matplotlib.pyplot` module
         mw.sns()  # returns `seaborn` module
+
+        # You can also import the module names from `matwrap`
+        from shinyutils.matwrap import mpl, plt, sns
+
+        fig = plt.figure()
+        ...
     """
 
     _rc_defaults_path = resource_filename("shinyutils", "data/mplcfg.json")
@@ -57,6 +63,7 @@ class MatWrap:
         style: str = "ticks",
         font: str = "Latin Modern Roman",
         latex_pkgs: Optional[List[str]] = None,
+        backend: Optional[str] = None,
         **rc_extra,
     ):
         """Configure matplotlib and seaborn.
@@ -66,6 +73,7 @@ class MatWrap:
             style: Seaborn style (`darkgrid`/`whitegrid`/`dark`/`white`/[`ticks`]).
             font: Font, passed directly to fontspec (default: `Latin Modern Roman`).
             latex_pkgs: List of packages to load in latex pgf preamble.
+            backend: Matplotlib backend to override default (pgf).
             rc_extra: Matplotlib params (will overwrite defaults).
         """
         rc = MatWrap._rc_defaults.copy()
@@ -76,6 +84,8 @@ class MatWrap:
             for pkg in reversed(latex_pkgs):
                 rc["pgf.preamble"].insert(0, rf"\usepackage{{{pkg}}}")
         rc["pgf.preamble"] = "\n".join(rc["pgf.preamble"])
+        if backend is not None:
+            rc["backend"] = backend
         rc.update(rc_extra)
 
         if cls._mpl is None:
@@ -83,8 +93,9 @@ class MatWrap:
             try:
                 import matplotlib
             except ImportError as e:
-                e.msg += ": install shinyutils[plotting] to use MatWrap"
-                raise e
+                raise ImportError(
+                    f"{e}: install shinyutils[plotting] to use MatWrap"
+                ) from None
 
             cls._mpl = matplotlib
             cls._mpl_default_rc = cls._mpl.rcParams.copy()
@@ -95,8 +106,9 @@ class MatWrap:
             try:
                 import seaborn
             except ImportError as e:
-                e.msg += ": install shinyutils[plotting] to use MatWrap"
-                raise e
+                raise ImportError(
+                    f"{e}: install shinyutils[plotting] to use MatWrap"
+                ) from None
 
             cls._plt = matplotlib.pyplot
             cls._sns = seaborn
@@ -149,16 +161,16 @@ class MatWrap:
 
     @classmethod
     def palette(cls) -> List[str]:
-        """Color-blindness friendly palette of 8 colors in hex."""
+        """Color universal design palette."""
         return [
-            "#e41a1c",
-            "#6a3d9a",
+            "#000000",
+            "#e69f00",
+            "#56b4e9",
+            "#009e73",
+            "#f0e442",
+            "#0072b2",
             "#d55e00",
-            "#34495e",
-            "#377eb8",
-            "#4daf4a",
-            "#95a5a6",
-            "#222222",
+            "#cc79a7",
         ]
 
     @staticmethod
